"use client"

import { Icons } from '@/components/icons'
import { Button } from '@/components/ui/button'
import { Input } from '@/components/ui/input'
import { cn } from '@/lib/utils'
import { usePathname, useRouter, useSearchParams } from 'next/navigation'
import { useState } from 'react'

interface DocsSearchProps extends React.HTMLAttributes<HTMLFormElement> { }

export default function SearchInput({ className, ...props }: DocsSearchProps) {
    const router = useRouter()
    const pathname = usePathname()
    const searchParams = useSearchParams()

    const search = searchParams?.get("query")?.trim().toLowerCase() || ""

    const [searchQuery, setSearchQuery] = useState(
        pathname?.split("/")[1] === "search" ?
            decodeURIComponent(search)
            : "",
    )

    function onSearch(event: React.FormEvent) {
        event.preventDefault()

        if (pathname.startsWith("/games")) {
            if (!searchQuery) {
                router.push(pathname)
                return
            }

            const encoededQuery = encodeURIComponent(searchQuery)
            router.push(`/games?search=${encoededQuery}`)
        } else {
            if (!searchQuery.trim()) return
            router.push(`/search?query=${searchQuery}`)
        }
    }

    return (
        <form
            onSubmit={onSearch}
            className={cn("relative w-full flex justify-end items-center", className)}
            {...props}
        >
            <Input
                id='search'
                type="search"
                placeholder="Search..."
                className="rounded-full pr-12"
                value={searchQuery}
                onChange={(event) => setSearchQuery(event.target.value)}
            />

            <Button
                type="submit"
                size="option"
                className="absolute align-middle h-8 px-2.5 mr-1">
                <Icons.arrowRight />
            </Button>
        </form>
    )
}